## this program is for lincense authorize

### it use cpuid and servertime and clienttime to verify the request with the premaked lic file

####  clienttime get method,for example use javascript:
    # current time
    # var d = new Date()
    # ct=d.getTime()
    
    # set time
    # var d = new Date("2023-5-12")
    # ct=d.getTime()
### the lic file is made by anthor tools

### if you are intertested , you can contact with me 

### my email : gisfanmachel@gmail.com